@@ -10,7 +10,8 @@ from code_analysis.configure import *
 
 class RegularRule:
     _DEFAULT_LIST = [
-        'c', 'h', 'hpp', 'hxx', 'cpp', 'cc', 'cxx', 'C', 'c++', 'java', 'js', 'vue', 'ts', 'ftl', 'properties', 'jsp'
+        'c', 'h', 'hpp', 'hxx', 'cpp', 'cc', 'cxx', 'C', 'c++', 'java',
+        'js', 'vue', 'ts', 'tsx', 'less', 'scss', 'ftl', 'properties', 'jsp'
     ]
 
     def get(self, item='c'):
@@ -22,13 +23,16 @@ class RegularRule:
         if item == 'py':
             file_type = "PY"
             file_suffix = PY_RULE
+        elif item == "xml":
+            file_type = "FRONTEND"
+            file_suffix = XML_RULE
+        elif item == "html":
+            file_type = "DEFAULT"
+            file_suffix = HTML_RULE
         elif item in self._DEFAULT_LIST:
             file_type = "DEFAULT"
             file_suffix = DEFAULT_RULE
-        elif item in ['xml', 'html']:
-            file_type = "FRONTEND"
-            file_suffix = ML_RULE
-        elif item in ['css', 'scss', 'sass', 'php']:
+        elif item in ['css', 'sass', 'php']:
             file_type = "FRONTEND"
             file_suffix = CSS_PHP_RULE
         elif item == 'jsp':
@@ -44,7 +48,7 @@ class RegularRule:
             file_type = "SH"
             file_suffix = SH_RULE
         else:
-            return True, False, False, False
+            return True, False
 
         return self._str2re(file_suffix, file_type)
 
@@ -52,20 +56,20 @@ class RegularRule:
     def _str2re(_rule: dict, file_type: str):
         if file_type == "FRONTEND":
             line = _rule.get('line_comment').split(' ')
-            line_re_str = '{0[0]}[\s\S]*?{0[1]}'.format(line)
+            line_re_str = u'{0[0]}[\s\S]*?{0[1]}'.format(line)
             line_regular = re.compile(r'%s' % line_re_str, re.S)
         elif file_type == "SH":
             line = _rule.get('line_comment').split(' ')[:1]
-            line_re_str = '%s(.*?)\n' % line[0]
+            line_re_str = u'%s(.*?)\n' % line[0]
             line_regular = re.compile(r'%s' % line_re_str, re.S)
-            return line_regular, line, line_regular, line
+            return line_regular, line_regular
         else:
             line = _rule.get('line_comment').split(' ')[:1]
-            line_re_str = '%s.*?(?=\n)' % line[0]
+            line_re_str = u'%s.*?(?=\n)' % line[0]
             line_regular = re.compile(r'%s' % line_re_str, re.S)
 
         block = _rule.get('block_comment').split(' ')
-        block_re_str = '{0[0]}[\s\S]*?{0[1]}'.format(block)
+        block_re_str = u'{0[0]}[\s\S]*?{0[1]}'.format(block)
         block_regular = re.compile(r'%s' % block_re_str, re.S)
 
-        return block_regular, block, line_regular, line
+        return block_regular, line_regular
